@@ -1,14 +1,13 @@
 from rest_framework.decorators import action
 from rest_framework.response import Response
 
+from bluedot_rest_framework import import_string
 from bluedot_rest_framework.utils.viewsets import CustomModelViewSet, user_perform_create
 from bluedot_rest_framework.utils.jwt_token import jwt_get_userid_handler
-from bluedot_rest_framework.settings import api_settings
-from django.utils.module_loading import import_string
 
-EventRegister = import_string(api_settings.EVENT['register']['models'])
-EventRegisterSerializer = import_string(
-    api_settings.EVENT['register']['serializers'])
+
+EventRegister = import_string('EVENT.register.models')
+EventRegisterSerializer = import_string('EVENT.register.serializers')
 
 
 class EventRegisterView(CustomModelViewSet):
