@@ -1,8 +1,8 @@
 from bluedot_rest_framework.utils.serializers import CustomSerializer
-from bluedot_rest_framework.settings import api_settings
-from django.utils.module_loading import import_string
+from bluedot_rest_framework import import_string
 
-EventSpeaker = import_string(api_settings.EVENT['speaker']['models'])
+
+EventSpeaker = import_string('EVENT.speaker.models')
 
 
 class EventSpeakerSerializer(CustomSerializer):
