@@ -6,7 +6,7 @@ from rest_framework.settings import APISettings
 
 USER_SETTINGS = getattr(settings, 'BLUEDOT_REST_FRAMEWORK', None)
 
-DEFAULTS = {
+DEFAULTS_SETTINGS = {
     'EVENT': {
         'models': 'bluedot_rest_framework.event.models.Event',
         'serializers': 'bluedot_rest_framework.event.serializers.EventSerializer',
@@ -79,25 +79,51 @@ DEFAULTS = {
         'models': 'bluedot_rest_framework.user.models.User',
         'serializers': 'bluedot_rest_framework.user.serializers.UserSerializer',
         'views': 'bluedot_rest_framework.user.views.UserView',
+    },
+    'WECHAT': {
+        'MINIPROGRAM': {
+            'APPID': '',
+            'SECRET': ''
+        },
+        'OFFIACCOUNT': {
+            'APPID': 'wx7c33b1edc5934d81',
+            'SECRET': 'da0330d7394e1f620b43ccd118646d5e',
+            'TOKEN': 'X1GOUqQcLipgwyhVYMPfagGIFqgbDHlF',
+            'EncodingAESKey': 'uLVsTEJU6M20Ks1h2Bc9Rh4Y2FGG5IFrLcEhOjtmdqy'
+        },
+        'redis_client': 'redis://127.0.0.1:6379/0'
+    },
+    'UTILS': {
+        'AES': {
+            'iv': 'aSEDKOOuic5BDks1',
+            'key': '9B1niuSzcISIHV5i',
+        },
+        'OSS': {
+            'access_key_id': 'LTAI4Fsv96kxGi33PNNUd4z6',
+            'access_key_secret': 'qGbegKc3fmVYZ2Z7qowlXCyTq04iTm',
+            'endpoint': 'http://oss-cn-beijing.aliyuncs.com',
+            'bucket_name': 'cpa-global'
+        }
     }
 }
 
 # List of settings that may be in string import notation.
 IMPORT_STRINGS = (
     'EVENT',
-    'USER'
+    'USER',
+    'WECHAT',
+    'UTILS',
 )
 
-api_settings = APISettings(USER_SETTINGS, DEFAULTS)
-# event_settings = api_settings.EVENT
+
+def merge_settings(DEFAULTS_SETTINGS, USER_SETTINGS):
+    for key in USER_SETTINGS:
+        if isinstance(USER_SETTINGS[key], dict) and isinstance(DEFAULTS_SETTINGS[key], dict):
+            merge_settings(DEFAULTS_SETTINGS[key], USER_SETTINGS[key])
+        else:
+            DEFAULTS_SETTINGS[key] = USER_SETTINGS[key]
+    return DEFAULTS_SETTINGS
 
 
-# def transform_objects(settings):
-#     for key in settings:
-#         if isinstance(settings[key], dict):
-#             transform_objects(settings[key])
-#         else:
-#             print(settings[key])
-
-
-# transform_objects(event_settings)
+DEFAULTS_SETTINGS = merge_settings(DEFAULTS_SETTINGS, USER_SETTINGS)
+api_settings = APISettings(DEFAULTS_SETTINGS, DEFAULTS_SETTINGS)
